package zetabank.model;

import java.util.List;

public class Finanziamento {
	private TipoFinanziamento tipo;
	private int durata;
	private Periodicita periodicitaRimborso;
	private List<Rata> rate;
	private double capitaleFinanziato;
	
	public Finanziamento(TipoFinanziamento tipo, int durata,
			Periodicita periodicitaRimborso, List<Rata> rate,
			double capitaleFinanziato) {
		if (tipo == null)
			throw new IllegalArgumentException("tipo");
		if (durata <= 0)
			throw new IllegalArgumentException("durata");
		if (periodicitaRimborso == null || !tipo.getPeriodicitaAmmesse().contains(periodicitaRimborso))
			throw new IllegalArgumentException("periodicitaRimborso");
		if (rate == null || rate.isEmpty())
			throw new IllegalArgumentException("rate");
		if (capitaleFinanziato <= 0)
			throw new IllegalArgumentException("capitaleFinanziato");
		
		this.tipo = tipo;
		this.durata = durata;
		this.periodicitaRimborso = periodicitaRimborso;
		this.rate = rate;
		this.capitaleFinanziato = capitaleFinanziato;
	}

	public TipoFinanziamento getTipo() {
		return tipo;
	}

	public int getDurata() {
		return durata;
	}

	public Periodicita getPeriodicitaRimborso() {
		return periodicitaRimborso;
	}

	public List<Rata> getRate() {
		return rate;
	}

	public double getCapitaleFinanziato() {
		return capitaleFinanziato;
	}

	public double sommaTotaleInteressi(){
		double somma = 0;
		for (Rata r: getRate()) somma += r.getQuotaInteressi();
		return somma;
	}
	
	public String toString() {
		return "Finanziamento [tipo=" + tipo + ", durata=" + durata
				+ ", periodicitaRimborso=" + periodicitaRimborso + ", rate="
				+ rate + ", capitaleFinanziato=" + capitaleFinanziato + "]";
	}
		
}
